Enum pallet_sudo::pallet::Call [−][src]
pub enum Call<T: Config> {
sudo {
call: Box<<T as Config>::Call>,
},
sudo_unchecked_weight {
call: Box<<T as Config>::Call>,
weight: Weight,
},
set_key {
new: <T::Lookup as StaticLookup>::Source,
},
sudo_as {
who: <T::Lookup as StaticLookup>::Source,
call: Box<<T as Config>::Call>,
},
// some variants omitted
}Expand description
Contains one variant per dispatchable that can be called by an extrinsic.
Variants
Authenticates the sudo key and dispatches a function call with Root origin.
The dispatch origin for this call must be Signed.
- O(1).
- Limited storage reads.
- One DB write (event).
- Weight of derivative
callexecution + 10,000.
Authenticates the sudo key and dispatches a function call with Root origin.
This function does not check the weight of the call, and instead allows the
Sudo user to specify the weight of the call.
The dispatch origin for this call must be Signed.
- O(1).
- The weight of this call is defined by the caller.
Authenticates the current sudo key and sets the given AccountId (new) as the new sudo
key.
The dispatch origin for this call must be Signed.
- O(1).
- Limited storage reads.
- One DB change.
Fields of set_key
new: <T::Lookup as StaticLookup>::SourceAuthenticates the sudo key and dispatches a function call with Signed origin from
a given account.
The dispatch origin for this call must be Signed.
- O(1).
- Limited storage reads.
- One DB write (event).
- Weight of derivative
callexecution + 10,000.
Implementations
Create a call with the variant sudo.
Create a call with the variant sudo_unchecked_weight.
Create a call with the variant set_key.
pub fn new_call_variant_sudo_as(
who: <T::Lookup as StaticLookup>::Source,
call: Box<<T as Config>::Call>
) -> Self
pub fn new_call_variant_sudo_as(
who: <T::Lookup as StaticLookup>::Source,
call: Box<<T as Config>::Call>
) -> Self
Create a call with the variant sudo_as.