pub struct Pallet<T>(/* private fields */);Expand description
The Pallet struct, the main type that implements traits and standalone
functions within the pallet.
Implementations
Sourceimpl<T: Config> Pallet<T>
impl<T: Config> Pallet<T>
Sourcepub fn sudo(
origin: OriginFor<T>,
call: Box<<T as Config>::RuntimeCall>,
) -> DispatchResultWithPostInfo
pub fn sudo( origin: OriginFor<T>, call: Box<<T as Config>::RuntimeCall>, ) -> DispatchResultWithPostInfo
Authenticates the sudo key and dispatches a function call with Root origin.
Sourcepub fn sudo_unchecked_weight(
origin: OriginFor<T>,
call: Box<<T as Config>::RuntimeCall>,
weight: Weight,
) -> DispatchResultWithPostInfo
pub fn sudo_unchecked_weight( origin: OriginFor<T>, call: Box<<T as Config>::RuntimeCall>, weight: Weight, ) -> DispatchResultWithPostInfo
Authenticates the sudo key and dispatches a function call with Root origin.
This function does not check the weight of the call, and instead allows the
Sudo user to specify the weight of the call.
The dispatch origin for this call must be Signed.
Sourcepub fn set_key(
origin: OriginFor<T>,
new: <<T as Config>::Lookup as StaticLookup>::Source,
) -> DispatchResultWithPostInfo
pub fn set_key( origin: OriginFor<T>, new: <<T as Config>::Lookup as StaticLookup>::Source, ) -> DispatchResultWithPostInfo
Authenticates the current sudo key and sets the given AccountId (new) as the new sudo
key.
Sourcepub fn sudo_as(
origin: OriginFor<T>,
who: <<T as Config>::Lookup as StaticLookup>::Source,
call: Box<<T as Config>::RuntimeCall>,
) -> DispatchResultWithPostInfo
pub fn sudo_as( origin: OriginFor<T>, who: <<T as Config>::Lookup as StaticLookup>::Source, call: Box<<T as Config>::RuntimeCall>, ) -> DispatchResultWithPostInfo
Authenticates the sudo key and dispatches a function call with Signed origin from
a given account.
The dispatch origin for this call must be Signed.
Sourcepub fn remove_key(origin: OriginFor<T>) -> DispatchResultWithPostInfo
pub fn remove_key(origin: OriginFor<T>) -> DispatchResultWithPostInfo
Permanently removes the sudo key.
This cannot be un-done.